#
# spec file for package procmail
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           procmail
Version:        3.22
Release:        270.14
Summary:        A program for local e-mail delivery
License:        Artistic-1.0 or GPL-2.0+
Group:          Productivity/Networking/Email/Clients
Url:            http://www.procmail.org/
Source0:        ftp://ftp.informatik.rwth-aachen.de/pub/packages/procmail/procmail-%{version}.tar.gz
Source1:        procmail-%{version}-patches.tar.bz2
Patch0:         procmail-%{version}-mailstat.patch
Patch1:         procmail-%{version}.dif
Patch2:         procmail-cflags.dif
Patch3:         procmail-%{version}-headerconcat.dif
Patch4:         procmail-%{version}-owl-truncate.dif
Patch5:         procmail-%{version}-autoconf.dif
Patch6:         procmail-%{version}-ipv6.patch
# PATCH-FIX-SUSE Heap-overflow in procmail's formail utility when processing specially-crafted email headers (bnc#894999)
Patch7:         procmail-%{version}-CVE-2014-3618.patch
BuildRequires:  pcre-devel
BuildRequires:  postfix
Requires:       /bin/sed
Recommends:     /usr/bin/mimencode
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Sendmail calls procmail to deliver email into a local folder. Procmail
can be configured to store e-mail in different folders.

%prep
%setup -q -b1
for p in ../procmail-%{version}-patches/* ; do
    test -e $p || break
    echo Patch $p
    patch -s -p1 --fuzz=0 < $p
done
%patch0 -p0
%patch1 -p0
%patch2 -p0
%patch3 -p0
%patch4 -p0
%patch5 -p0
%patch6 -p1
%patch7 -p0
sed -ri '\@^/\*@,\@\*/@{ s@^(/\*[^*]*)(/\*)@\1\*/ \2@; }' config.h
sed -ri '\@^/\*@,\@\*/@{ s@^(/\*[^*]*)(/\*)@\1\*/ \2@; }' src/includes.h
sed -ri '\@^#.*[[:blank:]]+/\*[^/]*$@M,\@\*/$@{ s@(^[[:blank:]]+)/\*@\1  @;}' src/includes.h

%build
    cflags ()
    {
	local flag=$1; shift
	local var=$1; shift
	local gold
	test -n "${flag}" -a -n "${var}" || return
	case "${!var}" in
	*${flag}*) return
	esac
	if type ld.gold > /dev/null 2>&1 ; then
	    gold=-Wl,-fuse-ld=gold
	fi
	set -o noclobber
	case "$flag" in
	-Wl,*)
	    if echo 'int main () { return 0; }' | \
		${CC:-gcc} $RPM_OPT_FLAGS -Werror $gold $flag -o /dev/null -xc - > /dev/null 2>&1 ; then
		eval $var=\${$var:+\$$var\ }$flag
	    fi
	    rm -f ldtest.c
	    ;;
	*)
	    if ${CC:-gcc} -Werror $gold $flag -S -o /dev/null -xc /dev/null > /dev/null 2>&1 ; then
		eval $var=\${$var:+\$$var\ }$flag
	    fi
	    if ${CXX:-g++} -Werror $gold $flag -S -o /dev/null -xc++ /dev/null > /dev/null 2>&1 ; then
		eval $var=\${$var:+\$$var\ }$flag
	    fi
	esac
	set +o noclobber
    }
    RPM_OPT_FLAGS="%{optflags}"
    XCFLAGS="$(getconf LFS_CFLAGS)"
    cflags -fPIE                    RPM_OPT_FLAGS
    cflags -std=c89                 RPM_OPT_FLAGS
    cflags -Wno-parentheses         RPM_OPT_FLAGS
    cflags -Wno-sign-compare        RPM_OPT_FLAGS
    cflags -Wno-unprototyped-calls  RPM_OPT_FLAGS
    cflags -pipe                    RPM_OPT_FLAGS
    cflags -fno-strict-aliasing     XCFLAGS
    cflags -Wl,-O2                  LDFLAGS0
    cflags -Wl,--hash-size=8599     LDFLAGS0
    cflags -pie                     LDFLAGS0
    export RPM_OPT_FLAGS XCFLAGS LDFLAGS0
    make %{?_smp_mflags} XCFLAGS="${XCFLAGS}" MANDIR=%{_mandir} LDFLAGS0="${LDFLAGS0}"

%install
    mkdir -p %{buildroot}%{_mandir}/man{1,5} %{buildroot}%{_prefix}/bin
    make MANDIR=%{buildroot}%{_mandir} BINDIR=%{buildroot}%{_bindir} install
    install -m 644 man/mailstat.man %{buildroot}%{_mandir}/man1/mailstat.1

%files
%defattr(-,root,root)
%doc Artistic COPYING
%doc FAQ FEATURES README examples
%{_bindir}/formail
%{_bindir}/lockfile
%{_bindir}/mailstat
%{_bindir}/procmail
%{_mandir}/man1/formail.1.gz
%{_mandir}/man1/lockfile.1.gz
%{_mandir}/man1/procmail.1.gz
%{_mandir}/man1/mailstat.1.gz
%{_mandir}/man5/procmailex.5.gz
%{_mandir}/man5/procmailrc.5.gz
%{_mandir}/man5/procmailsc.5.gz

%changelog
* Mon Dec 29 2014 meissner@suse.com
- build with PIE
* Mon Dec 22 2014 dimstar@opensuse.org
- Drop .keyring and .sig files: procmail is signed using an MD5
  type key, which is no longer accepted by GPG 2.1
- Drop the usage of gpg-offline: we don't have keys to verify and
  the source validator performs the action transparent nowadays.
* Thu Sep  4 2014 werner@suse.de
- Correct licenses
- Add cflags() shell function to be able to check for compiler,
  linker, and assembler flags, that is if those are supported by
  the compiler, linker, or assembler.
* Thu Sep  4 2014 werner@suse.de
- Add patch procmail-3.22-CVE-2014-3618.patch to fix heap-overflow
  in procmail's formail utility when processing specially-crafted
  email headers (bnc#894999, CVE-2014-3618)
* Mon Apr 15 2013 idonmez@suse.com
- Cleanup spec file
- Add Source URL, see https://en.opensuse.org/SourceUrls
- Add GPG verification
* Thu Feb 28 2013 coolo@suse.com
- update license to new format
* Mon Nov 14 2011 werner@suse.de
- Go forward and add the patches from Debian
- Also add ipv6 patch from openmamba
- Adop or drop our own patches
- Do not sleep a second on NFS based home shares
- Support LMTP (rfc2033: Local Mail Transfer Protocol) server
* Tue Feb  8 2011 seife+obs@b1-systems.com
- the only thing that needs mimencode are the examples
  change the "Requires: mimencode" to "Recommends"
* Tue Dec 15 2009 jengelh@medozas.de
- enable parallel building
* Fri Nov 20 2009 werner@suse.de
- Fix that last fix (bnc#556509)
* Fri Jan 30 2009 od@suse.de
- assume RFC2822-compliant header continuation lines, do not cover
  up for older mail clients that insert more spacing (bnc#469222)
* Tue Nov 11 2008 kukuk@suse.de
- vacation is no required package
* Tue Mar  4 2008 werner@suse.de
- Avoid warnings due oldish C code of procmail
- Be sure that autoconf catchs missing pw_class
* Thu Jun 28 2007 werner@suse.de
- Be sure that standard programs are available in procmailrc
* Mon Jan  8 2007 werner@suse.de
- Use only fcntl(2) for locking, do not mix with flock(2) (#231845)
* Fri May 26 2006 schwab@suse.de
- Don't strip binaries.
* Thu May 11 2006 werner@suse.de
- Enable large file support (bug #174497)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jan 13 2006 werner@suse.de
- Fix the last bug fix to re-enable biff/comsat (bug #135883)
* Mon Nov  7 2005 werner@suse.de
- Do not truncate a folder if reached quota (bug #132530)
* Sun May  9 2004 od@suse.de
- fixed handling of folded headers: delete leading whitespace
* Fri Mar 26 2004 ro@suse.de
- added postfix to neededforbuild
* Mon Feb 23 2004 werner@suse.de
- Reenabled locking with fcntl.
* Mon Feb 23 2004 werner@suse.de
- Update to procmail 3.22 (includes maildir feature)
* Sun Jan 11 2004 adrian@suse.de
- build as user
* Mon Sep  1 2003 pthomas@suse.de
- Pass -fno-strict-aliasing to gcc, as regexp.c uses type punning
  and thus could be miscompiled.
* Wed May 28 2003 coolo@suse.de
- use BuildRoot
* Tue May 13 2003 mmj@suse.de
- Use %%defattr
* Wed Jan 22 2003 mmj@suse.de
- Enabled locking with fcntl as well
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Thu Jan 11 2001 werner@suse.de
- Update to 3.15.1 due security:
  * A race to create the mailspool would bounce one of the
    messages due to an internal error
  * LC_ in KEEPENV would preserve only the first LC_foo variable
  * Strip runtime linker variables (LD_*) from environment on
    all platforms
  * Drop duplicate and malformed environment entries
* Tue Jan  9 2001 werner@suse.de
- Update to 3.15 due to security issue
* Thu Nov 23 2000 werner@suse.de
- Update to 3.14
* Wed Jun  7 2000 ro@suse.de
- doc relocation
* Sun Feb 27 2000 kukuk@suse.de
- Move /usr/man -> /usr/share/man
* Mon Dec  6 1999 werner@suse.de
- Fix default PATH
* Fri Oct  1 1999 werner@suse.de
- New version 3.13.1
- Add procmail-maildir.patch (supporting of maildirs with ending '/')
- Add procmail-locking.patch (no locking for directories required)
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Fri Jul 17 1998 werner@suse.de
- Use mktemp
* Thu Jul 16 1998 werner@suse.de
- fix for mailstat script
* Mon Jul  7 1997 florian@suse.de
- update to version 3.11-pre7
- add docu files in /usr/doc/packages
* Thu Jan  2 1997 florian@suse.de
- Umstieg auf non-sgid-mail spool-Verzeichnis.
